@@ -134,7 +134,7 @@ class WebDriver(Driver):
         self._enable_mouse_support()
 
         self.write("\x1b[?25l")  # Hide cursor
-        self.write("\033[?1003h\n")
+        self.write("\033[?1003h")
 
         size = Size(80, 24) if self._size is None else Size(*self._size)
         event = events.Resize(size, size)
